infoblox
    * ``auth_user`` Specify the user to access the infoblox wapi

    * ``auth_psw`` Specify the password to access the infoblox wapi

    * ``ib_view`` Specify dns view to manage at the infoblox

    * ``ib_host`` Specify infoblox host exposing the wapi
